==> cuyo_1.8.5.orig.tar.gz: cuyo-1.8.5/src/global.h <==
/***************************************************************************
                          global.h  -  description
                             -------------------
    begin                : Mit Jul 12 22:54:51 MEST 2000
    copyright            : (C) 2000 by Immi
    email                : cuyo@pcpool.mathematik.uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GLOBAL_H
#define GLOBAL_H

#include <qstring.h>

#include "inkompatibel.h"



/* Name der Haupt-level-descr-Datei. (Prft, ob es
   schon definiert ist, fr den Fall, dass ich irgend wann auf die Idee
   komme, LEVELDESCR in config.h zu definieren.) */
#ifndef LEVELDESCR
#define LEVELDESCR "main.ld"
#endif





/* In dieser Datei werden all die Dinge definiert, von denen ich nicht
   wei, wo ich sie hin tun soll. Unter anderem ein paar globale Variablen. */


/** True, wenn -d bergeben wurde, d. h. im Debug-Modus. */
extern bool gDebug;


/** Pfad, wo das Cuyo-Programm liegt, das aufgerufen wurde (aus
    argv[0] extrahiert. Wird vom PfadIterator gebraucht, um nach
    Leveln zu suchen. */
extern __String gCuyoPfad;

/** True, wenn der Benutzer den Namen einer ld-Datei bergeben hat. */
extern bool gDateiUebergeben;

/** Wenn eine ld-Datei bergeben wurde, dann ist das der Name davon. */
extern __String gLevelDatei;




/** Entfernt von p alles, was nach dem ersten Punkt kommt. Ist dazu da
    um aus einem "bla.xpm", was unter pics steht, den Namen fr Programme
    zu extrahieren. */
__String picsEndungWeg(const __String & p);


/** d sollte ein Pfad mit Dateiname sein. Liefert nur den Pfad-Anteil
    zurck (d. h. alles vor dem letzten "/". Liefer "./", falls d keinen
    "/" enthlt. */
__String nimmPfad(__String d);




#endif

==> cuyo_2.1.0.orig.tar.gz: cuyo-2.1.0/src/global.h <==
/***************************************************************************
                          global.h  -  description
                             -------------------
    begin                : Mit Jul 12 22:54:51 MEST 2000
    copyright            : (C) 2000 by Immi
    email                : cuyo@pcpool.mathematik.uni-freiburg.de

Modified 2002,2006,2008,2010,2011 by the cuyo developers

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GLOBAL_H
#define GLOBAL_H

class Str;


/* In dieser Datei werden all die Dinge definiert, von denen ich nicht
   wei, wo ich sie hin tun soll. Unter anderem ein paar globale Variablen. */


/** True, wenn -d bergeben wurde, d. h. im Debug-Modus. */
extern bool gDebug;

/** Pfad, wo das Cuyo-Programm liegt, das aufgerufen wurde (aus
    argv[0] extrahiert. Wird vom PfadIterator gebraucht, um nach
    Leveln zu suchen. */
extern Str gCuyoPfad;

/** True, wenn der Benutzer den Namen einer ld-Datei bergeben hat. */
extern bool gDateiUebergeben;

/** Wenn eine ld-Datei bergeben wurde, dann ist das der Name davon. */
extern Str gLevelDatei;





/** Entfernt von p alles, was nach dem ersten Punkt kommt. Ist dazu da
    um aus einem "bla.xpm", was unter pics steht, den Namen fr Programme
    zu extrahieren. */
Str picsEndungWeg(const Str & p);


/** d sollte ein Pfad mit Dateiname sein. Liefert nur den Pfad-Anteil
    zurck (d. h. alles vor dem letzten "/". Liefert "./", falls d keinen
    "/" enthlt. */
Str nimmPfad(Str d);


/** d sollte ein Pfad mit Dateiname sein. Liefert nur den nicht-Pfad-Anteil
    zurck (d. h. alles nach dem letzten "/". Liefert alles, falls d keinen
    "/" enthlt. */
Str vergissPfad(Str d);




#endif
